==> order-center-domain-3.0.0-CLOUD-DEV-20250409.072946-169-sources.jar: com/tydic/dyc/oc/components/ordSourceProcessor/impl/UocOrderSourceProcessorAgr.java <==
package com.tydic.dyc.oc.components.ordSourceProcessor.impl;

import cn.hutool.core.util.ObjectUtil;
import com.tydic.dyc.oc.components.ordSourceProcessor.UocOrderSourceProcessor;
import com.tydic.dyc.oc.constants.UocDicConstant;
import com.tydic.dyc.oc.model.saleorder.sub.UocSaleOrderItem;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 标题:UocOrderSourceProcessorNoAgr
 * 说明:协议处理类
 * 时间:2022/4/6 14:45
 * 作者:田桂银
 */
@Component
public class UocOrderSourceProcessorAgr implements UocOrderSourceProcessor {

    @Override
    public List<List<UocSaleOrderItem>> splitSaleOrder(List<UocSaleOrderItem> reqSaleItemList) {
        List<List<UocSaleOrderItem>> retList = new ArrayList<>();
        //根据供应商拆单
        Map<String, List<UocSaleOrderItem>> supMap = reqSaleItemList.stream().collect(Collectors.groupingBy(UocSaleOrderItem::getSupplierId));

        for (Map.Entry<String, List<UocSaleOrderItem>> entry : supMap.entrySet()) {
            //根据协议进行拆单
            Map<String, List<UocSaleOrderItem>> agrMap = entry.getValue().stream().collect(Collectors.groupingBy(UocSaleOrderItem::getAgreementId));
            for (Map.Entry<String, List<UocSaleOrderItem>> agrEntry : agrMap.entrySet()) {
                //根据计划id是否为空，分两波处理，非计划的一组，计划的再根据计划id拆一次单
                List<UocSaleOrderItem> noPlanList = agrEntry.getValue().stream().filter(item -> ObjectUtil.isEmpty(item.getPlanId())).collect(Collectors.toList());
                if (ObjectUtil.isNotEmpty(noPlanList)) {
                    retList.add(noPlanList);
                }
                List<UocSaleOrderItem> planList = agrEntry.getValue().stream().filter(item -> !ObjectUtil.isEmpty(item.getPlanId())).collect(Collectors.toList());
                if (ObjectUtil.isNotEmpty(planList)) {
                    retList.addAll(planList.stream().collect(Collectors.groupingBy(UocSaleOrderItem::getPlanId)).values());
                }
            }
        }

        return retList;
    }

    @Override
    public Integer skuSource() {
        return UocDicConstant.ORDER_SOURCE.AGR_GENERATE;
    }
}

==> order-center-domain-3.2.2-CLOUD-DEV-20240517.090613-17-sources.jar: com/tydic/dyc/oc/components/ordSourceProcessor/impl/UocOrderSourceProcessorAgr.java <==
package com.tydic.dyc.oc.components.ordSourceProcessor.impl;

import cn.hutool.core.util.ObjectUtil;
import com.tydic.dyc.oc.components.ordSourceProcessor.UocOrderSourceProcessor;
import com.tydic.dyc.oc.constants.UocDicConstant;
import com.tydic.dyc.oc.model.saleorder.sub.UocSaleOrderItem;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 标题:UocOrderSourceProcessorNoAgr
 * 说明:协议处理类
 * 时间:2022/4/6 14:45
 * 作者:田桂银
 */
@Component
public class UocOrderSourceProcessorAgr implements UocOrderSourceProcessor {

    @Override
    public List<List<UocSaleOrderItem>> splitSaleOrder(List<UocSaleOrderItem> reqSaleItemList) {
        List<List<UocSaleOrderItem>> retList = new ArrayList<>();
        //根据供应商拆单
        Map<String, List<UocSaleOrderItem>> supMap = reqSaleItemList.stream().collect(Collectors.groupingBy(UocSaleOrderItem::getSupplierId));

        for (Map.Entry<String, List<UocSaleOrderItem>> entry : supMap.entrySet()) {
            //根据协议进行拆单
            Map<String, List<UocSaleOrderItem>> agrMap = entry.getValue().stream().collect(Collectors.groupingBy(UocSaleOrderItem::getAgreementId));
            for (Map.Entry<String, List<UocSaleOrderItem>> agrEntry : agrMap.entrySet()) {
                //根据计划id是否为空，分两波处理，非计划的一组，计划的再根据计划id拆一次单
                /*List<UocSaleOrderItem> noPlanList = agrEntry.getValue().stream().filter(item -> ObjectUtil.isEmpty(item.getPlanId())).collect(Collectors.toList());
                if (ObjectUtil.isNotEmpty(noPlanList)) {
                    retList.add(noPlanList);
                }
                List<UocSaleOrderItem> planList = agrEntry.getValue().stream().filter(item -> !ObjectUtil.isEmpty(item.getPlanId())).collect(Collectors.toList());
                if (ObjectUtil.isNotEmpty(planList)) {
                    retList.addAll(planList.stream().collect(Collectors.groupingBy(UocSaleOrderItem::getPlanId)).values());
                }*/
                //按预算拆单
                Map<Long, List<UocSaleOrderItem>> budgetMap = agrEntry.getValue().stream().collect(Collectors.groupingBy(UocSaleOrderItem::getBudgetId));
                for (Map.Entry<Long, List<UocSaleOrderItem>> budgetEntry : budgetMap.entrySet()) {
                    retList.add(budgetEntry.getValue());
                }
            }
        }

        return retList;
    }

    @Override
    public Integer skuSource() {
        return UocDicConstant.ORDER_SOURCE.AGR_GENERATE;
    }
}
